@@ -612,6 +612,9 @@ def auto_restart(args):
     # allow us to gracefully unwind and stop the observer
     termination_signals = {signal.SIGTERM, signal.SIGINT}
 
+    if hasattr(signal, "SIGHUP"):
+        termination_signals.add(signal.SIGHUP)
+
     def handler_termination_signal(_signum, _frame):
         # Neuter all signals so that we don't attempt a double shutdown
         for signum in termination_signals:
