@@ -1,5 +1,4 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
+# coding: utf-8
 #
 # Copyright 2014 Thomas Amland <thomas.amland@gmail.com>
 #
@@ -14,16 +13,3 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from sys import version_info
-
-if version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
-
-try:
-    from Queue import Queue  # Python 2
-except ImportError:
-    from queue import Queue  # Python 3
-
-__all__ = ["unittest", "Queue"]
